"use client";

import { useRouter } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { addCart } from "@/servers/actions/cart-action";
import { useSlug } from "@/servers/data/use-slug";
import Cookies from "js-cookie";
import { useEffect, useState, useTransition } from "react";
import { toast } from "sonner";
import CustomerReviews from "./customer-reviews";
import SubmitReviewForm from "./review-form";

// Import the new components
import { useTranslations } from "next-intl";
import CartButtons from "./product-info/cart-buttons";
import ProductDescription from "./product-info/product-description";
import ProductFeatures from "./product-info/product-features";
import ProductHeader from "./product-info/product-header";
import ProductImages from "./product-info/product-images";
import ProductPrice from "./product-info/product-price";
import ProductQuantity from "./product-info/product-quantity";
import ProductRating from "./product-info/product-rating";

interface ProductInfoClientProps {
	slug: string;
}

export function ProductInfoClient({
	slug,
}: ProductInfoClientProps) {
	const { data } = useSlug(slug, "product", "product");
	const router = useRouter();
	const t = useTranslations("Common");

	const [isPending, startTransition] = useTransition();
	const [quantity, setQuantity] = useState(1);
	const [selectedImage, setSelectedImage] = useState("");
	const [rating, setRating] = useState(data?.ratings || 0);

	useEffect(() => {
		setSelectedImage(data?.images?.find((image: any) => image?.id === data?.thumbnail_id)?.image_path);
		setRating(data?.ratings?.[0]?.rating || 0);
	}, [data]);

	const handleQuantityChange = (value: number) => {
		if (value >= 1) {
			setQuantity(value);
		}
	};

	const handleAddToCart = () => {
		const _session = Cookies.get("__t");

		if (!_session) {
			toast.error(t("Please login to add to cart"));
			return;
		}

		startTransition(async () => {
			try {
				const result = await addCart({
					product_id: data?.id,
					quantity: quantity,
				});
				if (result?.success) {
					toast.success(t("The product has been added to the cart"), {
						style: { backgroundColor: "green", color: "white" },
					});

					setQuantity(1);

				} else {
					toast.error(t(result?.message?.replace(".", "")));
					if (result?.status === 401) router.push("/login");
				}
			} catch (error: any) {
				console.log("error: ", error);
				toast.error("Something went wrong");
			}
		});
	};

	console.log("data: ", data);

	return (
		<section className="container mx-auto py-16">
			<div className="flex flex-col items-start justify-between gap-10 md:flex-row">
				{/* Product Info */}
				<div className={cn("flex flex-[50%] flex-col gap-5")}>
					<ProductHeader data={data} />
					<ProductPrice basePrice={data?.base_price} />
					<ProductRating rating={rating} />
					<ProductDescription data={data} />
					<ProductQuantity
						quantity={quantity}
						handleQuantityChange={handleQuantityChange}
					/>
					<ProductFeatures features={data?.features} />
					<CartButtons
						isPending={isPending}
						handleAddToCart={handleAddToCart}
					/>
				</div>

				{/* Product Image */}
				<ProductImages
					images={data?.images}
					selectedImage={selectedImage}
					setSelectedImage={setSelectedImage}
					data={data}
				/>
			</div>
			<SubmitReviewForm product={{
				id: data?.id,
				image: data?.images?.[data?.images?.length - 1],
				can_review: data?.can_review,
				user_review: data?.user_review
			}} />
			<CustomerReviews reviews={data?.ratings} />
		</section>
	);
}




